"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

var _Button = _interopRequireDefault(require("../Button"));

var _iconsReact = require("@rocketsoftware/icons-react");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function renderActionButtons(type, onClick) {
  var stop = _iconsReact.Stop16;
  var reboot = _iconsReact.Restart16;
  var maintenance = _iconsReact.Tools16;
  var svg;

  if (type === 'Stop') {
    svg = stop;
    return /*#__PURE__*/_react.default.createElement(_Button.default, {
      className: "bx--resource-header__button",
      onClick: onClick,
      small: true,
      renderIcon: svg,
      kind: "ghost"
    }, type);
  } else if (type === 'Reboot') {
    svg = reboot;
    return /*#__PURE__*/_react.default.createElement(_Button.default, {
      className: "bx--resource-header__button",
      onClick: onClick,
      renderIcon: svg,
      small: true,
      kind: "ghost"
    }, type);
  } else if (type === 'Maintenance') {
    svg = maintenance;
    return /*#__PURE__*/_react.default.createElement(_Button.default, {
      className: "bx--resource-header__button",
      onClick: onClick,
      small: true,
      renderIcon: svg,
      kind: "ghost"
    }, type);
  }
} // function renderTitleStatus() {
//   return (
//     <div className="bx--resource-header__status-item bx--resource-header__status-item--active">
//       Active
//     </div>
//   );
// }


function renderStatus(status) {
  return status.map(function (item, i) {
    var statusClasses = (0, _classnames.default)({
      'bx--resource-header__status-item--active': item.isTrue
    }, 'bx--resource-header__status-item');
    return /*#__PURE__*/_react.default.createElement("div", {
      key: i,
      className: statusClasses
    }, item.text);
  });
}

var ResourceHeader = function ResourceHeader(_ref) {
  var className = _ref.className,
      icon = _ref.icon,
      isActive = _ref.isActive,
      renderActions = _ref.renderActions,
      renderBreadcrumbs = _ref.renderBreadcrumbs,
      renderMaintenance = _ref.renderMaintenance,
      renderReboot = _ref.renderReboot,
      renderStop = _ref.renderStop,
      status = _ref.status,
      subtitle = _ref.subtitle,
      title = _ref.title;
  var resourceHeaderClasses = (0, _classnames.default)('bx--resource-header', className);
  return /*#__PURE__*/_react.default.createElement("header", {
    className: resourceHeaderClasses
  }, /*#__PURE__*/_react.default.createElement("section", {
    className: "bx--resource-header__container"
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: "bx--resource-header__container--left"
  }, renderBreadcrumbs && renderBreadcrumbs(), /*#__PURE__*/_react.default.createElement("div", {
    className: "bx--resource-header__content-container"
  }, icon && /*#__PURE__*/_react.default.createElement("div", {
    className: "bx--resource-header__icon"
  }, icon), /*#__PURE__*/_react.default.createElement("div", {
    className: "bx--resource-header__content"
  }, title && /*#__PURE__*/_react.default.createElement("div", {
    className: "bx--resource-header__title"
  }, /*#__PURE__*/_react.default.createElement("h3", null, title), isActive && /*#__PURE__*/_react.default.createElement("div", {
    className: "bx--resource-header__status-item bx--resource-header__status-item--active"
  }, "Active")), /*#__PURE__*/_react.default.createElement("div", {
    className: "bx--resource-header__subtitle"
  }, subtitle && subtitle.map(function (item, key) {
    return /*#__PURE__*/_react.default.createElement("span", {
      key: key
    }, item, " \xA0");
  }))))), /*#__PURE__*/_react.default.createElement("div", {
    className: "bx--resource-header__container--right"
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: "bx--resource-header__status"
  }, /*#__PURE__*/_react.default.createElement("div", null, status && renderStatus(status))), /*#__PURE__*/_react.default.createElement("div", {
    className: "bx--resource-header__actions"
  }, renderStop && renderActionButtons('Stop', renderStop), renderReboot && renderActionButtons('Reboot', renderReboot), renderMaintenance && renderActionButtons('Maintenance', renderMaintenance), renderActions && renderActions()))));
};

ResourceHeader.propTypes = {
  /**
   * The CSS class names of the resource header
   */
  className: _propTypes.default.string,

  /**
   * The icon to be rendered in the header.
   */
  icon: _propTypes.default.node,

  /**
   * `true` to show the status text next to the resource header title.
   */
  isActive: _propTypes.default.bool,

  /**
   * The function used to create and show an action dropdown.
   */
  renderActions: _propTypes.default.func,

  /**
   * The function used to create and show breadcrumbs.
   */
  renderBreadcrumbs: _propTypes.default.func,

  /**
   * The function used to show and attach actions to the maintenance icon
   */
  renderMaintenance: _propTypes.default.func,

  /**
   * The function used to show and attach actions to the reboot icon
   */
  renderReboot: _propTypes.default.func,

  /**
   * The function used to show and attach actions to the stop icon
   */
  renderStop: _propTypes.default.func,

  /**
   * The array used to show status text above the action icons
   */
  status: _propTypes.default.array,

  /**
   * The array used to show subtitle text below the resource header title
   */
  subtitle: _propTypes.default.array,

  /**
   * The title of the resource header
   */
  title: _propTypes.default.string
};
var _default = ResourceHeader;
exports.default = _default;